==> lowcode-react-render-1.0.6.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useState } from 'react';
import ReactRenderer from '@alilc/lowcode-react-renderer';
import appHelper from './appHelper';
import { byCodeQuerySchema, getSchemaPreview } from './services/mockService';
var SamplePreview = function SamplePreview() {
  var _useState = useState({}),
    data = _useState[0],
    setData = _useState[1];
  function init() {
    return _init.apply(this, arguments);
  }
  function _init() {
    _init = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            byCodeQuerySchema('FORM6882ADBEA4014B6F9D6DF397489488F2').then(function (res) {
              if (res.success) {
                var _res$data;
                var dataSource = JSON.parse(((_res$data = res.data) === null || _res$data === void 0 ? void 0 : _res$data.content) || '{}');
                getSchemaPreview({
                  dataSource: dataSource
                }).then(function (result) {
                  setData(_extends({}, result));
                });
              }
            });
          case 1:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return _init.apply(this, arguments);
  }
  var _ref = data,
    schema = _ref.schema,
    components = _ref.components,
    _ref$i18n = _ref.i18n,
    i18n = _ref$i18n === void 0 ? {} : _ref$i18n;
  if (!schema || !components) {
    init();
    return /*#__PURE__*/React.createElement("div", null, " ");
  }
  return /*#__PURE__*/React.createElement("div", {
    className: "lowcode-plugin-sample-preview"
  }, /*#__PURE__*/React.createElement(ReactRenderer, {
    className: "lowcode-plugin-sample-preview-content",
    schema: schema,
    components: components,
    messages: i18n,
    appHelper: appHelper
  }));
};
export default SamplePreview;

==> lowcode-react-render-1.0.9.tgz: package/es/index.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import React, { useState } from 'react';
import ReactRenderer from '@alilc/lowcode-react-renderer';
import appHelper from './appHelper';
import { byCodeQuerySchema, getSchemaPreview } from './services/mockService';
var SamplePreview = function SamplePreview() {
  var _useState = useState({}),
    data = _useState[0],
    setData = _useState[1];
  function init() {
    return _init.apply(this, arguments);
  }
  function _init() {
    _init = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee() {
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            byCodeQuerySchema('FORM6882ADBEA4014B6F9D6DF397489488F2').then(function (_ref2) {
              var res = _ref2.data;
              if (res.success) {
                var _res$data;
                var dataSource = JSON.parse(((_res$data = res.data) === null || _res$data === void 0 ? void 0 : _res$data.content) || '{}');
                getSchemaPreview({
                  dataSource: dataSource
                }).then(function (result) {
                  setData(_extends({}, result));
                });
              }
            });
          case 1:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return _init.apply(this, arguments);
  }
  var _ref = data,
    schema = _ref.schema,
    components = _ref.components,
    _ref$i18n = _ref.i18n,
    i18n = _ref$i18n === void 0 ? {} : _ref$i18n;
  if (!schema || !components) {
    init();
    return /*#__PURE__*/React.createElement("div", null, " ");
  }
  return /*#__PURE__*/React.createElement("div", {
    className: "lowcode-plugin-sample-preview"
  }, /*#__PURE__*/React.createElement(ReactRenderer, {
    className: "lowcode-plugin-sample-preview-content",
    schema: schema,
    components: components,
    messages: i18n,
    appHelper: appHelper
  }));
};
export default SamplePreview;
